package net.blumia.pcmdroid.ui.screen.main

import androidx.compose.foundation.Image
import androidx.compose.foundation.layout.*
import androidx.compose.material.*
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.*
import androidx.compose.material.icons.rounded.PlayArrow
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.vector.ImageVector
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import kotlinx.coroutines.launch
import net.blumia.pcmdroid.R

@Preview(showBackground = true)
@OptIn(ExperimentalMaterialApi::class)
@Composable
fun NowPlaying() {
    Row(
        modifier = Modifier
            .fillMaxWidth()
            .height(56.dp),
        verticalAlignment = Alignment.CenterVertically,
    ) {
        Image(
            painter = painterResource(id = R.drawable.ic_launcher_background),
            contentDescription = "Album cover",
        )

        ListItem(
            text = {
                Text(
                    text = "Not playing at all.",
                )
            },
            trailing = {
                IconButton(onClick = { /*TODO*/ }) {
                    Icon(imageVector = Icons.Rounded.PlayArrow, contentDescription = "Menu")
                }
            }
        )


    }
}

@Preview(showBackground = true)
@OptIn(ExperimentalMaterialApi::class)
@Composable
fun DrawerContent(
    addServerActionTriggered: () -> Unit = {},
    settingsActionTriggered: () -> Unit = {},
) {
    Row(modifier = Modifier.fillMaxSize()) {
        var selectedItem by remember { mutableStateOf<Int?>(null) }
        val items = listOf<String>()
        val icons = listOf<ImageVector>()
        NavigationRail {
            items.forEachIndexed { index, item ->
                NavigationRailItem(
                    icon = {
                        Icon(
                            icons[index], item
                        )
                    },
                    label = {
                        Text(item)
                    },
                    selected = selectedItem == index,
                    onClick = { /*TODO*/ }
                )
            }

            NavigationRailItem(
                icon = { Icon(Icons.Filled.AddCircle, null) },
                label = { Text("Add") },
                selected = false,
                onClick = addServerActionTriggered,
            )

            Spacer(modifier = Modifier.weight(1f))

            NavigationRailItem(
                icon = { Icon(Icons.Filled.Settings, null) },
                label = { Text("Settings") },
                selected = false,
                onClick = settingsActionTriggered,
            )
        }

        Column(modifier = Modifier.weight(1f)) {
            ListItem(
                text = {
                    Text(
                        text = "No server selected",
                        style = MaterialTheme.typography.subtitle1
                    )
                },
                trailing = {
                    IconButton(onClick = { /*TODO*/ }) {
                        Icon(imageVector = Icons.Filled.MoreVert, contentDescription = "Menu")
                    }
                }
            )

            Divider()
        }
    }
}

@Preview(showBackground = true)
@Composable
fun MainPlayer(
    addServerActionTriggered: () -> Unit = {},
    settingsActionTriggered: () -> Unit = {},
) {
    val drawerState = rememberDrawerState(initialValue = DrawerValue.Closed)
    val drawerScope = rememberCoroutineScope()
    ModalDrawer(
        drawerState = drawerState,
        drawerContent = {
            DrawerContent(
                addServerActionTriggered = addServerActionTriggered,
                settingsActionTriggered = settingsActionTriggered,
            )
        }
    ) {
        Scaffold(
            topBar = {
                TopAppBar(
                    title = { Text("Private Cloud Music") },
                    navigationIcon = {
                        IconButton(onClick = {
                            drawerScope.launch {
                                drawerState.open()
                            }
                        }) {
                            Icon(imageVector = Icons.Filled.Menu, contentDescription = "Open drawer")
                        }
                    },
                    actions = {
                        IconButton(onClick = { /*TODO*/ }) {
                            Icon(imageVector = Icons.Filled.MoreVert, contentDescription = "Menu")
                        }
                    }
                )
            }
        ) {
            Column(
                modifier = Modifier.fillMaxSize()
            ) {
                Column(modifier = Modifier.weight(1f, fill = true)) {
                    //
                }
                NowPlaying()
            }
        }
    }

}
